==> haskell-wai-conduit-3.0.0.4-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-conduit
version: 3.0.0.4
id: wai-conduit-3.0.0.4-I3IAQ9D6ZIz2poqh0zgai9
key: wai-conduit-3.0.0.4-I3IAQ9D6ZIz2poqh0zgai9
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/yesodweb/wai
synopsis: conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.
category: Web, Conduit
abi: 3818da8bf45205414632d882a380b486
exposed: True
exposed-modules:
    Network.Wai.Conduit
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/wai-conduit-3.0.0.4
hs-libraries: HSwai-conduit-3.0.0.4-I3IAQ9D6ZIz2poqh0zgai9
depends:
    base-4.11.1.0 wai-3.2.1.2-LKLIDbQRtqgEPtmIr3MYaf
    conduit-1.3.0.3-5ZsOzo28L26JRNfLzW387B transformers-0.5.5.0
    bytestring-0.10.8.2 http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             wai-3.2.1.2-LKLIDbQRtqgEPtmIr3MYaf=8fef4b7f1f92cc00d34b31969465d409
             conduit-1.3.0.3-5ZsOzo28L26JRNfLzW387B=4f322a960d59e7167ba56eb1269967d6
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX=c36ea90c1caed733a7293143960ab603
haddock-interfaces: /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html: /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-conduit-3.0.0.4-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-conduit
version: 3.0.0.4
id: wai-conduit-3.0.0.4-12oB8y6N6P8EaJvqC6s0Iz
key: wai-conduit-3.0.0.4-12oB8y6N6P8EaJvqC6s0Iz
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/yesodweb/wai
synopsis: conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.
category: Web, Conduit
abi: a238b0bd4270f9b3b1f385e295968eb0
exposed: True
exposed-modules:
    Network.Wai.Conduit
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/wai-conduit-3.0.0.4
hs-libraries: HSwai-conduit-3.0.0.4-12oB8y6N6P8EaJvqC6s0Iz
depends:
    base-4.11.1.0 wai-3.2.1.2-2H9p9HQiwTJLLqNxJrJ7sw
    conduit-1.3.0.3-LmObnhjlBlXKWT3aaj2Pgm transformers-0.5.5.0
    bytestring-0.10.8.2 http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             wai-3.2.1.2-2H9p9HQiwTJLLqNxJrJ7sw=4dcfd1f19878874b7a3f1edbd12d60e9
             conduit-1.3.0.3-LmObnhjlBlXKWT3aaj2Pgm=535591a208ecba6a439708afbfef5621
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq=681a4d4f5ae8e517c4372dabe00b35c0
haddock-interfaces: /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html: /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
